@@ -765,7 +765,7 @@ class ER:
                     left, bracket, rest = obj_label.partition("-->")
                     block, bracket, right = rest.partition("<--")
                     new_obj_label = left + right
-                    print(["checking", new_label, new_obj_label])
+                    if self.debug: print(["checking", new_label, new_obj_label])
                     if new_label == new_obj_label:
                         return potentialNode
 
